@@ -20,21 +20,25 @@ test_that("Results for example of second order cone programming with JuliaCall",
 
     X <- Variable(c(2, 2))
     y <- Variable()
-    p <- minimize(vecnorm(X) + y, 2 * X <= 1, t(X) + y >= 1, X >= 0, y >= 0)
+    p <- minimize(norm(vec(X)) + y, 2 * X <= 1, t(X) + y >= 1, X >= 0, y >= 0)
     cvx_optim(p)
 
     ## The R version with XRJulia directly
 
-    ev <- XRJulia::RJulia()
-    ev$Command("using Convex")
-    ev$Command("X = Variable(2, 2)")
-    ev$Command("y = Variable()")
-    ev$Command("p = minimize(vecnorm(X) + y, 2 * X <= 1, X' + y >= 1, X >= 0, y >= 0)")
-    ev$Command("solve!(p)")
+    # ev <- XRJulia::RJulia()
+
+    ## The R version with JuliaCall directly
+
+    ev <- JuliaCall::julia_setup()
+    ev$command("using Convex")
+    ev$command("X = Variable(2, 2)")
+    ev$command("y = Variable()")
+    ev$command("p = minimize(norm(vec(X)) + y, 2 * X <= 1, X' + y >= 1, X >= 0, y >= 0)")
+    ev$command("solve!(p, SCSSolver())")
 
     ## Compare the results
 
-    expect_equal(optval(p), ev$Eval("p.optval"))
-    expect_equal(value(X), ev$Eval("X.value", .get = TRUE))
-    expect_equal(value(y), ev$Eval("evaluate(y)", .get = TRUE))
+    expect_equal(optval(p), ev$eval("p.optval"))
+    expect_equal(value(X), ev$eval("X.value")) ##, .get = TRUE))
+    expect_equal(value(y), ev$eval("evaluate(y)")) ##, .get = TRUE))
 })
